==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_meteringmarketplace/type_defs.py <==
"""
Type annotations for meteringmarketplace service type definitions.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_meteringmarketplace/type_defs/)

Usage::

    ```python
    from types_boto3_meteringmarketplace.type_defs import ResponseMetadataTypeDef

    data: ResponseMetadataTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from datetime import datetime
from typing import Dict, List, Sequence, Union

from .literals import UsageRecordResultStatusType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "BatchMeterUsageRequestRequestTypeDef",
    "BatchMeterUsageResultTypeDef",
    "MeterUsageRequestRequestTypeDef",
    "MeterUsageResultTypeDef",
    "RegisterUsageRequestRequestTypeDef",
    "RegisterUsageResultTypeDef",
    "ResolveCustomerRequestRequestTypeDef",
    "ResolveCustomerResultTypeDef",
    "ResponseMetadataTypeDef",
    "TagTypeDef",
    "TimestampTypeDef",
    "UsageAllocationOutputTypeDef",
    "UsageAllocationTypeDef",
    "UsageAllocationUnionTypeDef",
    "UsageRecordOutputTypeDef",
    "UsageRecordResultTypeDef",
    "UsageRecordTypeDef",
    "UsageRecordUnionTypeDef",
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class RegisterUsageRequestRequestTypeDef(TypedDict):
    ProductCode: str
    PublicKeyVersion: int
    Nonce: NotRequired[str]


class ResolveCustomerRequestRequestTypeDef(TypedDict):
    RegistrationToken: str


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class MeterUsageResultTypeDef(TypedDict):
    MeteringRecordId: str
    ResponseMetadata: ResponseMetadataTypeDef


class RegisterUsageResultTypeDef(TypedDict):
    PublicKeyRotationTimestamp: datetime
    Signature: str
    ResponseMetadata: ResponseMetadataTypeDef


class ResolveCustomerResultTypeDef(TypedDict):
    CustomerIdentifier: str
    ProductCode: str
    CustomerAWSAccountId: str
    ResponseMetadata: ResponseMetadataTypeDef


class UsageAllocationOutputTypeDef(TypedDict):
    AllocatedUsageQuantity: int
    Tags: NotRequired[List[TagTypeDef]]


class UsageAllocationTypeDef(TypedDict):
    AllocatedUsageQuantity: int
    Tags: NotRequired[Sequence[TagTypeDef]]


class UsageRecordOutputTypeDef(TypedDict):
    Timestamp: datetime
    CustomerIdentifier: str
    Dimension: str
    Quantity: NotRequired[int]
    UsageAllocations: NotRequired[List[UsageAllocationOutputTypeDef]]


UsageAllocationUnionTypeDef = Union[UsageAllocationTypeDef, UsageAllocationOutputTypeDef]


class UsageRecordResultTypeDef(TypedDict):
    UsageRecord: NotRequired[UsageRecordOutputTypeDef]
    MeteringRecordId: NotRequired[str]
    Status: NotRequired[UsageRecordResultStatusType]


class MeterUsageRequestRequestTypeDef(TypedDict):
    ProductCode: str
    Timestamp: TimestampTypeDef
    UsageDimension: str
    UsageQuantity: NotRequired[int]
    DryRun: NotRequired[bool]
    UsageAllocations: NotRequired[Sequence[UsageAllocationUnionTypeDef]]


class UsageRecordTypeDef(TypedDict):
    Timestamp: TimestampTypeDef
    CustomerIdentifier: str
    Dimension: str
    Quantity: NotRequired[int]
    UsageAllocations: NotRequired[Sequence[UsageAllocationUnionTypeDef]]


class BatchMeterUsageResultTypeDef(TypedDict):
    Results: List[UsageRecordResultTypeDef]
    UnprocessedRecords: List[UsageRecordOutputTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


UsageRecordUnionTypeDef = Union[UsageRecordTypeDef, UsageRecordOutputTypeDef]


class BatchMeterUsageRequestRequestTypeDef(TypedDict):
    UsageRecords: Sequence[UsageRecordUnionTypeDef]
    ProductCode: str

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_meteringmarketplace/type_defs.py <==
"""
Type annotations for meteringmarketplace service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_meteringmarketplace/type_defs/)

Usage::

    ```python
    from types_boto3_meteringmarketplace.type_defs import ResponseMetadataTypeDef

    data: ResponseMetadataTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Sequence, Union

from .literals import UsageRecordResultStatusType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "BatchMeterUsageRequestRequestTypeDef",
    "BatchMeterUsageResultTypeDef",
    "MeterUsageRequestRequestTypeDef",
    "MeterUsageResultTypeDef",
    "RegisterUsageRequestRequestTypeDef",
    "RegisterUsageResultTypeDef",
    "ResolveCustomerRequestRequestTypeDef",
    "ResolveCustomerResultTypeDef",
    "ResponseMetadataTypeDef",
    "TagTypeDef",
    "TimestampTypeDef",
    "UsageAllocationOutputTypeDef",
    "UsageAllocationTypeDef",
    "UsageAllocationUnionTypeDef",
    "UsageRecordOutputTypeDef",
    "UsageRecordResultTypeDef",
    "UsageRecordTypeDef",
    "UsageRecordUnionTypeDef",
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class RegisterUsageRequestRequestTypeDef(TypedDict):
    ProductCode: str
    PublicKeyVersion: int
    Nonce: NotRequired[str]


class ResolveCustomerRequestRequestTypeDef(TypedDict):
    RegistrationToken: str


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class MeterUsageResultTypeDef(TypedDict):
    MeteringRecordId: str
    ResponseMetadata: ResponseMetadataTypeDef


class RegisterUsageResultTypeDef(TypedDict):
    PublicKeyRotationTimestamp: datetime
    Signature: str
    ResponseMetadata: ResponseMetadataTypeDef


class ResolveCustomerResultTypeDef(TypedDict):
    CustomerIdentifier: str
    ProductCode: str
    CustomerAWSAccountId: str
    ResponseMetadata: ResponseMetadataTypeDef


class UsageAllocationOutputTypeDef(TypedDict):
    AllocatedUsageQuantity: int
    Tags: NotRequired[list[TagTypeDef]]


class UsageAllocationTypeDef(TypedDict):
    AllocatedUsageQuantity: int
    Tags: NotRequired[Sequence[TagTypeDef]]


class UsageRecordOutputTypeDef(TypedDict):
    Timestamp: datetime
    CustomerIdentifier: str
    Dimension: str
    Quantity: NotRequired[int]
    UsageAllocations: NotRequired[list[UsageAllocationOutputTypeDef]]


UsageAllocationUnionTypeDef = Union[UsageAllocationTypeDef, UsageAllocationOutputTypeDef]


class UsageRecordResultTypeDef(TypedDict):
    UsageRecord: NotRequired[UsageRecordOutputTypeDef]
    MeteringRecordId: NotRequired[str]
    Status: NotRequired[UsageRecordResultStatusType]


class MeterUsageRequestRequestTypeDef(TypedDict):
    ProductCode: str
    Timestamp: TimestampTypeDef
    UsageDimension: str
    UsageQuantity: NotRequired[int]
    DryRun: NotRequired[bool]
    UsageAllocations: NotRequired[Sequence[UsageAllocationUnionTypeDef]]


class UsageRecordTypeDef(TypedDict):
    Timestamp: TimestampTypeDef
    CustomerIdentifier: str
    Dimension: str
    Quantity: NotRequired[int]
    UsageAllocations: NotRequired[Sequence[UsageAllocationUnionTypeDef]]


class BatchMeterUsageResultTypeDef(TypedDict):
    Results: list[UsageRecordResultTypeDef]
    UnprocessedRecords: list[UsageRecordOutputTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


UsageRecordUnionTypeDef = Union[UsageRecordTypeDef, UsageRecordOutputTypeDef]


class BatchMeterUsageRequestRequestTypeDef(TypedDict):
    UsageRecords: Sequence[UsageRecordUnionTypeDef]
    ProductCode: str
